OC.L10N.register(
    "notes",
    {
    "Notes" : "Նոթեր",
    "New note" : "Նոր նոթ",
    "Delete note" : "Ջնջել նոթը",
    "_%n word_::_%n words_" : ["%n բառ","%n բառ"]
},
"nplurals=2; plural=(n != 1);");
